@@ -174,6 +174,7 @@ def pull_repo(
     pattern: str = None,
     no_exist_create_modle: str = None,
     consistency_check: bool = True,
+    read_only: bool = False,
 ):
     """拉取代码"""
     start_time = time.perf_counter()
@@ -208,6 +209,9 @@ def pull_repo(
             utils.execute_cmd(["git", "checkout", branch], level="debug")
             utils.execute_cmd(["git", "merge"], level="debug")
         else:
+            # 远程库只读
+            if read_only:
+                raise ValueError(f"库{repo_name}远程分支不存在：{branch}")
             # 远程分支不存在时判断本地是否存在指定分支
             branch_exist = check_branch_exist(repo_path, branch)
             if branch_exist:
